@@ -177,7 +177,7 @@ def test_transfer_coin():
     c = libra_client.Client("testnet")
     c.mint_coins(a0.address, a0.auth_key_prefix, 1234_000, True)
     balance0 = c.get_balance(a0.address, retry=True)
-    balance1 = c.get_balance(a1.address, retry=True)
+    balance1 = 0
     ret = c.create_account(a0, a1.address, a1.auth_key_prefix, is_blocking=True)
     assert ret.raw_txn.sequence_number == 0
     ret = c.transfer_coin(a0, a1.address, 123, unit_price=1, is_blocking=True)
