@@ -27,8 +27,3 @@ def test_genesis():
     assert tx.events[3].type_tag.value.module == "LibraSystem"
     assert tx.events[3].type_tag.value.name == "DiscoverySetChangeEvent"
     amap = tx.to_json_serializable()
-    assert amap["raw_txn"]["sender"] == "0000000000000000000000000a550c18"
-    assert tx.raw_txn.sequence_number == 0
-    assert tx.raw_txn.max_gas_amount == 0
-    assert tx.raw_txn.gas_unit_price == 0
-    assert tx.raw_txn.expiration_time == 18446744073709551615
